Crate dots

Crate dots 

dots library

Structs

Cli
Command-line interface
Link
Represents a URL
World
This structure represents inputs to the application, with all paths resolved so the core of dots does not need to do any IO.
WritePath
Write contents to the path

Traits

PathExt
Extension trait for Path