World

Struct World 

pub struct World {
    pub root: PathBuf,
    pub links: Vec<Link>,
    pub files: Vec<File>,
}
This structure represents inputs to the application, with all paths resolved so the core of dots does not need to do any IO.

Fields

root: PathBuf

Path which contains the config file

links: Vec<Link>

Contents of the config file

files: Vec<File>

Files to create

Implementations

Source

impl World

pub fn process(self) -> Result<Analysis, Vec<Error>>

This function is the “core” of dots, it is pure and does no IO (except for logging)

We want to keep it like this as it makes it easier to reason about and test.

pub fn new(cwd: &Path) -> Result<Self, Vec<Error>>

Create the World